==> haskell-connection-0.2.5-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-connection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.5
id: connection-0.2.5-cec1287c35c167d5820c23cf4d477cb7
key: conne_17nQafBHHvx1GvFQAVJrI5
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
hs-libraries: HSconnection-0.2.5-17nQafBHHvx1GvFQAVJrI5
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
    tls-1.3.4-c263a34393f014f88bd2eb81ef38f476
    x509-1.6.3-88141428fd098325953c29fe36fd878e
    x509-store-1.6.1-43770428c1088301ba6ed013a258fa1c
    x509-system-1.6.3-ab7219111a5707b62bd7446e2bff807d
    x509-validation-1.6.3-0f89d8d374c48b8a0db3a2a9867fa82f
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.5-15-armv7h.pkg.tar.xz: usr/share/haskell/haskell-connection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.5
id: connection-0.2.5-bf0be896e72357cc1edd4c2cf71b9005
key: conne_Hu8yccNGqTDG5ozvmhBUKc
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/connection-0.2.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/connection-0.2.5
hs-libraries: HSconnection-0.2.5-Hu8yccNGqTDG5ozvmhBUKc
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    socks-0.5.4-8c65994a52c136dee4fd43556a5ac65b
    tls-1.3.4-a2c9d78849a8c3879b7fc9c50ab96b48
    x509-1.6.3-a26654b2694b0222cea24c9509df18b8
    x509-store-1.6.1-de9ae6187f4cf8a9fc0d902dd3099237
    x509-system-1.6.3-ea9efa0bc30d005c03db48465026b9c4
    x509-validation-1.6.3-aff871fef370c18650430c4d940ddd0e
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
